Documentation
¶
Index ¶
- Variables
- func GetTorznabID(cat RarbgCategory) int
- func IsSubtitleFileExtension(ext string) bool
- func IsVideoFileExtension(ext string) bool
- type AudioInfo
- type Cast
- type Character
- type Decade
- type Film
- type MediaInfo
- type MediaInfoJSONOutput
- type Pagination
- type Person
- type RarbgCategory
- type RarbgTorrent
- type SubsInfo
- type Subtitle
- type User
- type VideoInfo
- type Volume
- type VolumeFile
Constants ¶
This section is empty.
Variables ¶
var (
ErrOwnerAlreadyExists = errors.New("owner already exists")
)
Functions ¶
func GetTorznabID ¶ added in v1.1.0
func GetTorznabID(cat RarbgCategory) int
func IsSubtitleFileExtension ¶
IsSubtitleFileExtension checks if extension is corresponding to a known subtitle file extension See https://en.wikipedia.org/wiki/Category:Subtitle_file_formats
func IsVideoFileExtension ¶
IsVideoFileExtension checks if extension is corresponding to a known video file extension See https://en.wikipedia.org/wiki/Video_file_format
Types ¶
type Film ¶
type Film struct {
ID primitive.ObjectID `bson:"_id"`
VolumeFiles []VolumeFile `bson:"volume_files"`
Name string `bson:"name"` // Name fetched from filename
Resolution string `bson:"resolution"` // Resolution fetched from filename
ReleaseYear int `bson:"release_year"` // Release year fetched from filename
TMDBID int `bson:"tmdb_id"`
IMDbID string `bson:"imdb_id"`
// Fetched from online sources. Only these variables will be used by the template
Title string `bson:"title"`
OriginalTitle string `bson:"original_title"`
Year string `bson:"year"`
Runtime string `bson:"runtime"`
Tagline string `bson:"tagline"`
Overview string `bson:"overview"`
PosterPath string `bson:"poster_path"`
BackdropPath string `bson:"backdrop_path"`
Classification string `bson:"classification"`
IMDbRating string `bson:"imdb_rating"`
LetterboxdRating string `bson:"letterboxd_rating"`
Genres []string `bson:"genres"`
Directors []int64 `bson:"directors"`
Writers []int64 `bson:"writers"`
Characters []Character `bson:"characters"`
ProdCountries []string `bson:"prod_countries"`
}
func (Film) GetCastAndCrewIDs ¶
type MediaInfoJSONOutput ¶
type Pagination ¶ added in v1.0.3
Pagination represents a pagination display parameters
type RarbgCategory ¶ added in v1.1.0
type RarbgCategory string
const ( RarbgCatEbooks RarbgCategory = "ebooks" RarbgCatGamesPCIso RarbgCategory = "games_pc_iso" RarbgCatGamesPCRip RarbgCategory = "games_pc_rip" RarbgCatGamesPS3 RarbgCategory = "games_ps3" RarbgCatGamesPS4 RarbgCategory = "games_ps4" RarbgCatGamesXbox360 RarbgCategory = "games_xbox360" RarbgCatMovies RarbgCategory = "movies" RarbgCatMoviesBDFull RarbgCategory = "movies_bd_full" RarbgCatMoviesBDRemux RarbgCategory = "movies_bd_remux" RarbgCatMoviesX264 RarbgCategory = "movies_x264" RarbgCatMoviesX2643D RarbgCategory = "movies_x264_3d" RarbgCatMoviesX2644K RarbgCategory = "movies_x264_4k" RarbgCatMoviesX264720 RarbgCategory = "movies_x264_720" RarbgCatMoviesX265 RarbgCategory = "movies_x265" RarbgCatMoviesX2654K RarbgCategory = "movies_x265_4k" RarbgCatMoviesX2654KHDR RarbgCategory = "movies_x265_4k_hdr" RarbgCatMoviesXvid RarbgCategory = "movies_xvid" RarbgCatMoviesXvid720 RarbgCategory = "movies_xvid_720" RarbgCatMusicFlac RarbgCategory = "music_flac" RarbgCatMusicMp3 RarbgCategory = "music_mp3" RarbgCatSoftwarePCIso RarbgCategory = "software_pc_iso" RarbgCatTV RarbgCategory = "tv" RarbgCatTVSD RarbgCategory = "tv_sd" RarbgCatTVUHD RarbgCategory = "tv_uhd" RarbgCatXXX RarbgCategory = "xxx" )
type RarbgTorrent ¶ added in v1.1.0
type Subtitle ¶
func GetExternalSubtitles ¶
Fetches external subtitle files next to the media file. Subtitles file names must start with the media file name without extension. Ex: media: BigBuckBunny.mkv sub: BigBuckBunny.srt Language can be inferred from the subtitle file name, following ISO 639-1 codes. Ex: sub: BigBuckBunny.en.srt
type User ¶
type User struct {
ID primitive.ObjectID `bson:"_id"`
Name string `bson:"name"`
Password string `bson:"password"`
IsOwner bool `bson:"is_owner"`
IsAdmin bool `bson:"is_admin"`
}
User is a user
Click to show internal directories.
Click to hide internal directories.